@@ -67,6 +67,11 @@
 #include <QWebEngineScriptCollection>
 #include <QRegularExpression>
 #include <QtWebEngineWidgetsVersion>
+#include <QtWebEngineCoreVersion>
+
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+#include <QWebEngineNotification>
+#endif
 
 #ifdef Q_OS_WIN
 #include <QtWin>
@@ -146,6 +151,10 @@ MainApplication::MainApplication(int &argc, char** argv)
     }
 #endif
 
+    QByteArray flags = qgetenv("QTWEBENGINE_CHROMIUM_FLAGS");
+    flags.append(" --enable-features=WebRTCPipeWireCapturer");
+    qputenv("QTWEBENGINE_CHROMIUM_FLAGS", flags);
+
     QUrl startUrl;
     QString startProfile;
     QStringList messages;
@@ -155,7 +164,8 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     if (argc > 1) {
         CommandLineOptions cmd;
-        foreach (const CommandLineOptions::ActionPair &pair, cmd.getActions()) {
+        const auto actions = cmd.getActions();
+        for (const CommandLineOptions::ActionPair &pair : actions) {
             switch (pair.action) {
             case Qz::CL_StartWithoutAddons:
                 noAddons = true;
@@ -255,7 +265,7 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     if (isRunning()) {
         m_isClosing = true;
-        foreach (const QString &message, messages) {
+        for (const QString &message : qAsConst(messages)) {
             sendMessage(message);
         }
         return;
@@ -281,9 +291,20 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     Settings::createSettings(DataPaths::currentProfilePath() + QLatin1String("/settings.ini"));
 
-    m_webProfile = isPrivate() ? new QWebEngineProfile(this) : QWebEngineProfile::defaultProfile();
+    NetworkManager::registerSchemes();
+
+    m_webProfile = isPrivate() ? new QWebEngineProfile() : QWebEngineProfile::defaultProfile();
     connect(m_webProfile, &QWebEngineProfile::downloadRequested, this, &MainApplication::downloadRequested);
 
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    m_webProfile->setNotificationPresenter([&] (std::unique_ptr<QWebEngineNotification> notification) {
+        auto notifications = desktopNotifications();
+        notifications->showNotification(
+            QPixmap::fromImage(notification->icon()), notification->title(), notification->message()
+        );
+    });
+#endif
+
     m_networkManager = new NetworkManager(this);
 
     setupUserScripts();
@@ -455,7 +476,8 @@ void MainApplication::openSession(BrowserWindow* window, RestoreData &restoreDat
         window->restoreWindow(restoreData.windows.takeAt(0));
     }
 
-    foreach (const BrowserWindow::SavedWindow &data, restoreData.windows) {
+    const auto restoreWindows = restoreData.windows;
+    for (const BrowserWindow::SavedWindow &data : restoreWindows) {
         BrowserWindow* window = createWindow(Qz::BW_OtherRestoredWindow);
         window->restoreWindow(data);
     }
@@ -956,6 +978,11 @@ void MainApplication::loadSettings()
     webSettings->setAttribute(QWebEngineSettings::DnsPrefetchEnabled, settings.value(QSL("DNSPrefetch"), true).toBool());
 #endif
 
+#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    webSettings->setAttribute(QWebEngineSettings::PdfViewerEnabled, settings.value(QSL("intPDFViewer"), false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::ScreenCaptureEnabled, settings.value(QSL("screenCaptureEnabled"), false).toBool());
+#endif
+
     webSettings->setDefaultTextEncoding(settings.value(QSL("DefaultEncoding"), webSettings->defaultTextEncoding()).toString());
 
     setWheelScrollLines(settings.value(QSL("wheelScrollLines"), wheelScrollLines()).toInt());
